==> oct8ne-v.1.2.8.zip: oct8ne/views/js/oct8neadmin.js <==
/**
 * Prestashop module for Oct8ne
 * @author    Prestaquality.com
 * @copyright 2016 Prestaquality
 * @license   Commercial license see license.txt *
 * @category  Prestashop
 * @category  Module
 * Support by mail  : info@prestaquality.com
 */

$(document).ready(function () {
    showTextSearchEngine($(".search_engine").val());

    $(".search_engine").change(function () {
        showTextSearchEngine($(this).val());
    });

    function showTextSearchEngine(engine) {
        var doofinder_text = "Necesitará configurar las API KEY y los Hash en la configuración de doofinder para que funcione correctamente";
        var empathybroker_text = "Necesitará configurar la URL API brindada por Empathybroker para que funcione correctamente o bien cambiar solo la variable 'INSTANCE_ID'.";

        $(".url_api_motiveSearch").parents('.form-group').hide();
        $(".tenant_motiveSearch").parents('.form-group').hide();

        $(".url_api_empathybroker").parents('.form-group').hide();
        $(".url_api_apiSearch").parents('.form-group').hide();
        $(".tenant_apiSearch").parents('.form-group').hide();
        $(".search_engine").next().text("");
        $(".url_api_apiSearch").parents('.form-group').hide();
        $(".doofinder_api_key").parents('.form-group').hide();
        $(".doofinder_hash_id").parents('.form-group').hide();
        $(".doofinder_search_zone").parents('.form-group').hide();
        $(".doofinder_indices").parents('.form-group').hide();
        $(".doofinder_productId_property").parents('.form-group').hide();
        $(".doofinder_query_name").parents('.form-group').hide();
        $(".indexid_apiSearch").parents('.form-group').hide();
        $(".site_apiSearch").parents('.form-group').hide();
        $(".lang_apiSearch").parents('.form-group').hide();
        $(".endpoint_apiSearch").parents('.form-group').hide();
        $(".oct8ne-config-separator").parents('.form-group').hide();

        if (engine == 2) {
            $(".search_engine").next().text('');
            $(".search_engine").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".doofinder_search_zone").parents('.form-group').show();
            $(".doofinder_api_key").parents('.form-group').show();
            $(".doofinder_hash_id").parents('.form-group').show();
            $(".doofinder_indices").parents('.form-group').show();
            $(".doofinder_productId_property").parents('.form-group').show();
            $(".doofinder_query_name").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 3) {
            $(".url_api_empathybroker").next().text(empathybroker_text);
            $(".url_api_empathybroker").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".url_api_empathybroker").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 5) {
            $(".url_api_motiveSearch").next().text('');
            $(".url_api_motiveSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".url_api_motiveSearch").parents('.form-group').show();

            $(".tenant_motiveSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".tenant_motiveSearch").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 6) {
            $(".url_api_apiSearch").next().text('');
            $(".indexid_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".indexid_apiSearch").parents('.form-group').show();
            $(".site_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".site_apiSearch").parents('.form-group').show();
            $(".lang_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".lang_apiSearch").parents('.form-group').show();
            $(".endpoint_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".endpoint_apiSearch").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        }
        else {
            $(".search_engine").next().text("");
        }
    }
});

==> oct8ne-v.1.3.3.zip: oct8ne/views/js/oct8neadmin.js <==
/**
 * Prestashop module for Oct8ne
 * @author    Prestaquality.com
 * @copyright 2016 Prestaquality
 * @license   Commercial license see license.txt *
 * @category  Prestashop
 * @category  Module
 * Support by mail  : info@prestaquality.com
 */

$(document).ready(function () {
    showTextSearchEngine($(".search_engine").val());

    $(".search_engine").change(function () {
        showTextSearchEngine($(this).val());
    });

    function showTextSearchEngine(engine) {
        var doofinder_text = "Necesitará configurar las API KEY y los Hash en la configuración de doofinder para que funcione correctamente";
        var empathybroker_text = "Necesitará configurar la URL API brindada por Empathybroker para que funcione correctamente o bien cambiar solo la variable 'INSTANCE_ID'.";

        $(".url_api_motiveSearch").parents('.form-group').hide();
        $(".tenant_motiveSearch").parents('.form-group').hide();

        $(".url_api_empathybroker").parents('.form-group').hide();
        $(".url_api_apiSearch").parents('.form-group').hide();
        $(".tenant_apiSearch").parents('.form-group').hide();
        $(".search_engine").next().text("");
        $(".url_api_apiSearch").parents('.form-group').hide();
        $(".doofinder_api_key").parents('.form-group').hide();
        $(".doofinder_hash_id").parents('.form-group').hide();
        $(".doofinder_search_zone").parents('.form-group').hide();
        $(".doofinder_indices").parents('.form-group').hide();
        $(".doofinder_productId_property").parents('.form-group').hide();
        $(".doofinder_query_name").parents('.form-group').hide();
        $(".indexid_apiSearch").parents('.form-group').hide();
        $(".site_apiSearch").parents('.form-group').hide();
        $(".lang_apiSearch").parents('.form-group').hide();
        $(".endpoint_apiSearch").parents('.form-group').hide();
        $(".oct8ne-config-separator").parents('.form-group').hide();
        $(".empathy_api_endpoint").parents('.form-group').hide();
        $(".empathy_site_id").parents('.form-group').hide();
        $(".empathy_instance").parents('.form-group').hide();
        $(".empathy_lang").parents('.form-group').hide();
        $(".empathy_store").parents('.form-group').hide();
        $(".kimera_api_endpoint").parents('.form-group').hide();
        $(".kimera_store_id").parents('.form-group').hide();
        $(".kimera_api_key").parents('.form-group').hide();
        $(".kimera_lang").parents('.form-group').hide();
        $(".kimera_password").parents('.form-group').hide();
        $(".kimera_input_mode").parents('.form-group').hide();

        if (engine == 2) {
            $(".search_engine").next().text('');
            $(".search_engine").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".doofinder_search_zone").parents('.form-group').show();
            $(".doofinder_api_key").parents('.form-group').show();
            $(".doofinder_hash_id").parents('.form-group').show();
            $(".doofinder_indices").parents('.form-group').show();
            $(".doofinder_productId_property").parents('.form-group').show();
            $(".doofinder_query_name").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 3) {
            $(".url_api_empathybroker").next().text(empathybroker_text);
            $(".url_api_empathybroker").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".url_api_empathybroker").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 5) {
            $(".url_api_motiveSearch").next().text('');
            $(".url_api_motiveSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".url_api_motiveSearch").parents('.form-group').show();

            $(".tenant_motiveSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".tenant_motiveSearch").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 6) {
            $(".url_api_apiSearch").next().text('');
            $(".indexid_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".indexid_apiSearch").parents('.form-group').show();
            $(".site_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".site_apiSearch").parents('.form-group').show();
            $(".lang_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".lang_apiSearch").parents('.form-group').show();
            $(".endpoint_apiSearch").next().css({ "color": "red", "font-size": "105%", "font-weight": "bold" });
            $(".endpoint_apiSearch").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();

        } else if (engine == 8) {
            $(".empathy_api_endpoint").parents('.form-group').show();
            $(".empathy_site_id").parents('.form-group').show();
            $(".empathy_instance").parents('.form-group').show();
            $(".empathy_lang").parents('.form-group').show();
            $(".empathy_store").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();
        } else if (engine == 9) { // Kimera Search (NEW)
            $(".kimera_api_endpoint").parents('.form-group').show();
            $(".kimera_store_id").parents('.form-group').show();
            $(".kimera_api_key").parents('.form-group').show();
            $(".kimera_lang").parents('.form-group').show();
            $(".kimera_password").parents('.form-group').show();
            $(".kimera_input_mode").parents('.form-group').show();
            $(".oct8ne-config-separator").parents('.form-group').show();
            
        }

        else {
            $(".search_engine").next().text("");
        }

    }
});
